==> was-plugin-1.2.1.jar: com/xebialabs/deployit/plugin/was/step/create-wmq-queue.py <==
#
# Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
#
# Your use of Xebialabs Software and Documentation is subject to the Personal
# License Agreement.
# http://www.xebialabs.com/deployit-personal-edition-license-agreement
# You are granted a personal license (i) to use the Software for your own
# personal purposes which may be used in a production environment and/or (ii)
# to use the Documentation to develop your own plugins to the Software.
# ‚ÄúDocumentation‚Äù means the how to's and instructions (instruction videos)
# provided with the Software and/or available on the XebiaLabs website or other
# websites as well as the provided API documentation, tutorial and access to
# the source code of the Xebialabs plugins. You agree not to (i) lease, rent
# or sublicense the Software or Documentation to any third party, or otherwise
# use it except as permitted in this agreement; (ii) reverse engineer,
# decompile, disassemble, or otherwise attempt to determine source code or
# protocols from the Software, and/or to  (iii) copy the Software or
# Documentation (which includes the source code of the XebiaLabs plugins). You
# shall not create or attempt to create any derivative works from the Software
# except and only to the extent permitted by law. You will preserve XebiaLabs'
# copyright and legal notices on the Software and Documentation. XebiaLabs
# retains all rights not expressly granted to You in the Personal License
# Agreement.
#

import sys

jmsproviderid = AdminConfig.getid('/ServerCluster:'+ cluster['name'] + '/JMSProvider:WebSphere MQ JMS Provider')
if jmsproviderid == "":
    print "Deployit ERROR: Cannot find WebSphere MQ JMS Provider"
    sys.exit(1)

qargs = []
qargs.append(['name', q['name']])
qargs.append(['jndiName', q['jndiName']])
qargs.append(['baseQueueName', q['baseQueueName']])

print "Deployit INFO: Creating MQQueue"
AdminConfig.create('MQQueue', jmsproviderid, qargs)

AdminConfig.save()

==> was-plugin-1.2.2.jar: com/xebialabs/deployit/plugin/was/step/create-wmq-queue.py <==
#
# Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
#
# Your use of XebiaLabs Software and Documentation is subject to the Personal
# License Agreement.
#
# http://www.xebialabs.com/deployit-personal-edition-license-agreement
#
# You are granted a personal license (i) to use the Software for your own
# personal purposes which may be used in a production environment and/or (ii)
# to use the Documentation to develop your own plugins to the Software.
# "Documentation" means the how to's and instructions (instruction videos)
# provided with the Software and/or available on the XebiaLabs website or other
# websites as well as the provided API documentation, tutorial and access to
# the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
# or sublicense the Software or Documentation to any third party, or otherwise
# use it except as permitted in this agreement; (ii) reverse engineer,
# decompile, disassemble, or otherwise attempt to determine source code or
# protocols from the Software, and/or to  (iii) copy the Software or
# Documentation (which includes the source code of the XebiaLabs plugins). You
# shall not create or attempt to create any derivative works from the Software
# except and only to the extent permitted by law. You will preserve XebiaLabs'
# copyright and legal notices on the Software and Documentation. XebiaLabs
# retains all rights not expressly granted to You in the Personal License
# Agreement.
#

import sys

try:
    jmsproviderid = AdminConfig.getid('/ServerCluster:'+ cluster['name'] + '/JMSProvider:WebSphere MQ JMS Provider')
except NameError, ne:
    jmsproviderid = AdminConfig.getid('/Cell:' + cell['name'] + '/Node:' + node['name'] + '/Server:' + server['name'] + '/JMSProvider:WebSphere MQ JMS Provider')

if jmsproviderid == "":
    print "Deployit ERROR: Cannot find WebSphere MQ JMS Provider"
    sys.exit(1)

qargs = []
qargs.append(['name', q['name']])
qargs.append(['jndiName', q['jndiName']])
qargs.append(['baseQueueName', q['baseQueueName']])

print "Deployit INFO: Creating MQQueue"
AdminConfig.create('MQQueue', jmsproviderid, qargs)

AdminConfig.save()
